@@ -49,7 +49,7 @@ void KGraph::addLine(Arts::KGraphLine_impl *line)
 	lines.push_back(line);
 }
 
-void KGraph::redrawLine(Arts::KGraphLine_impl *line)
+void KGraph::redrawLine(Arts::KGraphLine_impl * /*line*/)
 {
 	repaint();
 }
@@ -126,7 +126,7 @@ void KGraph::mousePressEvent(QMouseEvent *e)
 				int dx = e->x() - p.x();
 				int dy = e->y() - p.y();
 
-				if(::sqrt(dx*dx + dy*dy) < 5.0)
+				if(::sqrt(double(dx*dx + dy*dy)) < 5.0)
 				{
 					selectedIndex = index;
 					selectedLine = gline;
@@ -141,11 +141,11 @@ void KGraph::mousePressEvent(QMouseEvent *e)
 		// erase point
 		if(e->button() == RightButton)
 		{
-			if(selectedIndex != 0 && selectedIndex != (selectedLine->_points.size()-1))
+			if(selectedIndex != 0 && selectedIndex != (( int )( selectedLine->_points.size() )-1))
 			{
 				vector<GraphPoint> points;
 	
-				for(int i=0;i<selectedLine->_points.size();i++)
+				for(int i=0;i<( int )selectedLine->_points.size();i++)
 				{
 					if(selectedIndex != i)
 						points.push_back(selectedLine->_points[i]);
@@ -185,7 +185,7 @@ void KGraph::mousePressEvent(QMouseEvent *e)
 						GraphPoint gp = q2gPoint(QPoint(e->x(),y));
 						vector<GraphPoint> newPoints;
 
-						for(int i=0;i<gline->_points.size();i++)
+						for(int i=0;i<( int )gline->_points.size();i++)
 						{
 							if(index == i)
 								newPoints.push_back(gp);
@@ -221,7 +221,7 @@ void KGraph::mouseMoveEvent(QMouseEvent *e)
 		vector<GraphPoint> points(selectedLine->_points);
 
 
-		if((points.size() <= selectedIndex)
+		if((( int )points.size() <= selectedIndex)
 		|| (fabs(selectedPoint.x-points[selectedIndex].x) > 0.000001)
 		|| (fabs(selectedPoint.y-points[selectedIndex].y) > 0.000001))
 		{
@@ -234,7 +234,7 @@ void KGraph::mouseMoveEvent(QMouseEvent *e)
 		GraphPoint gp = q2gPoint(pos);
 		selectedPoint.y = gp.y;
 
-		if(selectedIndex != 0 && selectedIndex != (points.size()-1))
+		if(selectedIndex != 0 && selectedIndex != (( int )( points.size() )-1))
 		{
 			float pixelsize = (maxx-minx)/float(width()-1);
 
@@ -242,7 +242,7 @@ void KGraph::mouseMoveEvent(QMouseEvent *e)
 			{
 				selectedPoint.x = points[selectedIndex-1].x+pixelsize;
 			}
-			else if(selectedIndex < (points.size()-1) && points[selectedIndex+1].x < gp.x)
+			else if(selectedIndex < (( int )( points.size() )-1) && points[selectedIndex+1].x < gp.x)
 			{
 				selectedPoint.x = points[selectedIndex+1].x-pixelsize;
 			}
@@ -256,8 +256,10 @@ void KGraph::mouseMoveEvent(QMouseEvent *e)
 	}
 }
 
-void KGraph::mouseReleaseEvent(QMouseEvent *e)
+void KGraph::mouseReleaseEvent(QMouseEvent *)
 {
 	selectedIndex = -1;
 	selectedLine = 0;
 }
+
+// vim: sw=4 ts=4
