@@ -18,6 +18,8 @@
 
 #include "artsplayer.h"
 
+#if HAVE_ARTS
+
 #include <kdebug.h>
 #include <kconfig.h>
 #include <kstandarddirs.h>
@@ -287,4 +289,6 @@ bool ArtsPlayer::serverRunning() const
 
 #include "artsplayer.moc"
 
+#endif 
+
 // vim: sw=4 ts=8 et
