@@ -18,6 +18,7 @@
 #include <qimage.h>
 
 #include "filehandle.h"
+#include "covermanager.h"
 
 class CoverInfo
 {
@@ -33,15 +34,34 @@ public:
     void clearCover();
     void setCover(const QImage &image = QImage());
 
+    // Use this to assign to a specific cover id.
+    void setCoverId(coverKey id);
+
+    /**
+     * This function sets the cover identifier for all tracks that have the
+     * same Artist and Album as this track, to the cover identifier of this
+     * track.
+     *
+     * @param overwriteExistingCovers If set to true, this function will always
+     *        apply the new cover to a track even if the track already had
+     *        a different cover set.
+     */
+    void applyCoverToWholeAlbum(bool overwriteExistingCovers = false) const;
+
+    coverKey coverId() const { return m_coverKey; }
+
     QPixmap pixmap(CoverSize size) const;
     void popup() const;
 
 private:
     QString coverLocation(CoverSize size) const;
+    bool convertOldStyleCover() const;
 
     FileHandle m_file;
     bool m_hasCover;
     bool m_haveCheckedForCover;
+    mutable coverKey m_coverKey;
+    mutable bool m_needsConverting;
 };
 #endif
 
