@@ -13,6 +13,15 @@
  *                                                                         *
  ***************************************************************************/
 
+/**
+ * Note to those who work here.  The preprocessor variables HAVE_ARTS and HAVE_GSTREAMER
+ * are ::ALWAYS DEFINED::.  You can't use #ifdef to see if they're present, you should just
+ * use #if.
+ *
+ * However, HAVE_AKODE is #define'd if present, and undefined if not present.
+ * - mpyne
+ */
+
 #include <kdebug.h>
 #include <klocale.h>
 
@@ -30,14 +39,13 @@
 #include "statuslabel.h"
 #include "actioncollection.h"
 #include "collectionlist.h"
+#include "coverinfo.h"
 #include "tag.h"
 
 #include "config.h"
 
 using namespace ActionCollection;
 
-PlayerManager *PlayerManager::m_instance = 0;
-
 enum PlayerManagerStatus { StatusStopped = -1, StatusPaused = 1, StatusPlaying = 2 };
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -51,9 +59,11 @@ static Player *createPlayer(int system = ArtsBackend)
 
     Player *p = 0;
     switch(system) {
+#ifdef HAVE_AKODE
     case AkodeBackend:
         p = new aKodePlayer;
         break;
+#endif
 #if HAVE_ARTS
     case ArtsBackend:
         p = new ArtsPlayer;
@@ -63,7 +73,7 @@ static Player *createPlayer(int system = ArtsBackend)
     case GStreamerBackend:
         p = new GStreamerPlayer;
         break;
-#endif
+#endif 
     default:
 #if HAVE_ARTS
         p = new ArtsPlayer;
@@ -89,7 +99,8 @@ PlayerManager::PlayerManager() :
     m_player(0),
     m_timer(0),
     m_noSeek(false),
-    m_muted(false)
+    m_muted(false),
+    m_setup(false)
 {
 // This class is the first thing constructed during program startup, and
 // therefore has no access to the widgets needed by the setup() method.
@@ -109,9 +120,8 @@ PlayerManager::~PlayerManager()
 
 PlayerManager *PlayerManager::instance() // static
 {
-    if(!m_instance)
-        m_instance = new PlayerManager;
-    return m_instance;
+    static PlayerManager manager;
+    return &manager;
 }
 
 bool PlayerManager::playing() const
@@ -183,12 +193,25 @@ QStringList PlayerManager::trackProperties()
 
 QString PlayerManager::trackProperty(const QString &property) const
 {
-    if(!playing())
+    if(!playing() && !paused())
         return QString::null;
 
     return m_file.property(property);
 }
 
+QPixmap PlayerManager::trackCover(const QString &size) const
+{
+    if(!playing() && !paused())
+        return QPixmap();
+
+    if(size.lower() == "small")
+        return m_file.coverInfo()->pixmap(CoverInfo::Thumbnail);
+    if(size.lower() == "large")
+        return m_file.coverInfo()->pixmap(CoverInfo::FullSize);
+
+    return QPixmap();
+}
+
 FileHandle PlayerManager::playingFile() const
 {
     return m_file;
@@ -199,7 +222,11 @@ QString PlayerManager::playingString() const
     if(!playing())
         return QString::null;
 
-    return m_file.tag()->artist() + " - " + m_file.tag()->title();
+    QString str = m_file.tag()->artist() + " - " + m_file.tag()->title();
+    if(m_file.tag()->artist().isEmpty())
+        str = m_file.tag()->title();
+
+    return str;
 }
 
 void PlayerManager::setPlaylistInterface(PlaylistInterface *interface)
@@ -217,14 +244,22 @@ KSelectAction *PlayerManager::playerSelectAction(QObject *parent) // static
     KSelectAction *action = 0;
     action = new KSelectAction(i18n("&Output To"), 0, parent, "outputSelect");
     QStringList l;
-    l <<
+
 #if HAVE_ARTS
-        i18n("aRts") <<
+    l << i18n("aRts");
 #endif
 #if HAVE_GSTREAMER
-        i18n("GStreamer") <<
+    l << i18n("GStreamer");
 #endif
-        i18n("aKode");
+#ifdef HAVE_AKODE
+    l << i18n("aKode");
+#endif
+
+    if(l.isEmpty()) {
+        kdError(65432) << "Your JuK seems to have no output backend possibilities.\n";
+        l << i18n("aKode"); // Looks like akode is the default backend.
+    }
+
     action->setItems(l);
     return action;
 }
@@ -262,6 +297,7 @@ void PlayerManager::play(const FileHandle &file)
     // Make sure that the player() actually starts before doing anything.
 
     if(!player()->playing()) {
+        kdWarning(65432) << "Unable to play " << file.absFilePath() << endl;
         stop();
         return;
     }
@@ -579,6 +615,10 @@ void PlayerManager::setup()
         return;
     }
 
+    if(m_setup)
+        return;
+    m_setup = true;
+
     // initialize action states
 
     action("pause")->setEnabled(false);
@@ -625,6 +665,25 @@ void PlayerManager::setup()
     connect(m_timer, SIGNAL(timeout()), this, SLOT(slotPollPlay()));
 }
 
+QString PlayerManager::randomPlayMode() const
+{
+    if(action<KToggleAction>("randomPlay")->isChecked())
+        return "Random";
+    if(action<KToggleAction>("albumRandomPlay")->isChecked())
+        return "AlbumRandom";
+    return "NoRandom";
+}
+
+void PlayerManager::setRandomPlayMode(const QString &randomMode)
+{
+    if(randomMode.lower() == "random")
+        action<KToggleAction>("randomPlay")->setChecked(true);
+    if(randomMode.lower() == "albumrandom")
+        action<KToggleAction>("albumRandomPlay")->setChecked(true);
+    if(randomMode.lower() == "norandom")
+        action<KToggleAction>("disableRandomPlay")->setChecked(true);
+}
+
 #include "playermanager.moc"
 
 // vim: set et ts=4 sw=4:
