@@ -28,6 +28,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 namespace Kaboodle
 {
+class UserInterface;
+
 class KaboodleApp : public KApplication
 {
 Q_OBJECT
@@ -36,6 +38,8 @@ public:
 	KaboodleApp();
 	virtual ~KaboodleApp();
 
+private:
+	UserInterface *ui;
 };
 }
 #endif
