@@ -1,5 +1,5 @@
 /*
- * $Id: cdinfo.c 332005 2004-07-23 11:47:58Z wheeler $
+ * $Id: cdinfo.c 466331 2005-10-02 10:58:26Z coolo $
  * 
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -589,7 +589,8 @@ wipe_cdinfo( void )
 				free(l->name);
 				free(l->list);
 			}
-			freeup( (char **)&thiscd.lists );
+			free(thiscd.lists);
+			thiscd.lists = NULL;
 		}
 
 		for (i = 0; i < cur_ntracks; i++)
@@ -635,12 +636,12 @@ stash_trkinfo( int track, char *songname, int contd, int avoid )
 }
 
 /*
- * new_list()
+ * new_playlist()
  *
  * Add a playlist to a CD.
  */
 struct wm_playlist *
-new_list(struct wm_cdinfo* cdinfo, char* listname)
+new_playlist(struct wm_cdinfo* cdinfo, char* listname)
 {
 	int	nlists = 0;
 	struct wm_playlist *l;
