@@ -1,7 +1,7 @@
 #ifndef WM_STRUCT_H
 #define WM_STRUCT_H
 /*
- * $Id: wm_struct.h 211874 2003-03-06 19:56:37Z kernalex $
+ * $Id: wm_struct.h 463503 2005-09-24 09:53:51Z mueller $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -104,7 +104,7 @@ struct wm_cdinfo
 /* The global variable "cd" points to the struct for the CD that's playing. */
 extern struct wm_cdinfo *cd;
 
-struct wm_playlist *new_list();
+extern struct wm_playlist *new_playlist();
 
 #define WM_STR_GENVENDOR "Generic"
 #define WM_STR_GENMODEL  "drive"
