@@ -17,8 +17,9 @@
 #include "inputDecoderYAF.h"
 #include "xplayerCommand.defs"
 #include "../yafcore/yafCommand.defs"
-
+#include <iostream>
   
+using namespace std;
 
 InputDecoderYAF::InputDecoderYAF(DecoderPlugin* plugin,
 				 YafOutputStream* output) 
@@ -61,9 +62,7 @@ void InputDecoderYAF::doSomething(){
 const char* InputDecoderYAF::processCommand(int command,const char* args){
 
   if (command == _PLAYER_UPDATE) {
-    cout << "got update"<<endl;
     int state=plugin->getStreamState();
-    cout << "stae is:"<<state<<endl;
     if (state == _STREAM_STATE_EOF) {
       if (getMajorMode() != _PLAYER_MAJOR_MODE_OFF) {
 	return processCommand(_PLAYER_OFF,"");
