@@ -27,7 +27,6 @@
 
 typedef float REAL;
 
-extern "C" {
 // The inline code works on intel only with egcs >= 1.1
 #ifdef __GNUC__
 #if (__GNUC__ < 2 || ( __GNUC__ == 2 && __GNUC_MINOR__ < 91 ) )
@@ -38,16 +37,9 @@ extern "C" {
 #endif
 #endif
 #endif
-#ifndef WIN32
 #include <math.h>
-#endif
 #include <stdlib.h>
 
-}
-#if defined WIN32
-  #include <math.h>
-#endif
-
 #ifndef M_PI
 #define MY_PI 3.14159265358979323846
 #else
