@@ -14,7 +14,7 @@ static KCmdLineOptions options[] =
 	KCmdLineLastOption
 };
 
-extern "C" int kdemain(int argc, char **argv)
+extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
 {
 	KAboutData aboutData("noatun", I18N_NOOP("Noatun"),
 	                     version, description, KAboutData::License_BSD,
