@@ -92,4 +92,4 @@ void CModule::ownerDeleted()
 	p->deleteLater();
 }
 
-#include <noatun/pref.moc>
+#include "pref.moc"
