@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000 Rik Hemsley (rikkus) <rik@kde.org>
- * 
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
  * deal in the Software without restriction, including without limitation the
@@ -190,7 +190,7 @@ ScrollingLabel::setScroll(bool b)
 	_update();
 }
 
-#include "noatun/scrollinglabel.moc"
+#include "scrollinglabel.moc"
 
 // vim:ts=2:sw=2:tw=78:noet
 
