@@ -44,4 +44,4 @@ void StereoButtonAction::toggleEnabled(void)
 
 }
 
-#include "noatun/stereobuttonaction.moc"
+#include "stereobuttonaction.moc"
