@@ -8,11 +8,15 @@
  ***************************************************************************/
 
 #include "kjbutton.h"
+#include "kjbutton.moc"
 #include "kjloader.h"
+#include "kjprefs.h"
 
-//#include "kjvis.h"
+#include <noatun/pref.h>
 #include <noatun/player.h>
+#include <noatun/vequalizer.h>
 
+#include <qcursor.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kpixmap.h>
@@ -20,15 +24,16 @@
 #include <kurl.h>
 #include <kfiledialog.h>
 #include <khelpmenu.h>
+#include <kpopupmenu.h>
 
 /*******************************************
  * KJButton
  *******************************************/
 
 KJButton::KJButton(const QStringList &i, KJLoader *parent)
-	: KJWidget(parent), mTitle(i[0]), mShowPressed(false)
+	: QObject(0), KJWidget(parent), mTitle(i[0]), mShowPressed(false)
 {
-//	kdDebug(66666) << "new button: " << i[0].latin1() << endl;
+//	kdDebug(66666) << k_funcinfo << "new button: " << i[0].latin1() << endl;
 	mPushedPixmap = (i.count() >= 7);
 
 	// get the rectangle
@@ -45,29 +50,55 @@ KJButton::KJButton(const QStringList &i, KJLoader *parent)
 	// can be either BMPx where x is a number representing one
 	// of the background-images
 	// or darken which means just darken the button on click
-	for ( QStringList::Iterator it = temp.begin(); it != temp.end(); ++it )
+	bool gotBack = false; // in case any of these keys is duplicated
+	for(QStringList::Iterator it = temp.begin(); it != temp.end(); ++it)
 	{
-		if( (*it).contains("bmp") )
+		if((*it).contains("bmp"))
 		{
-//			kdDebug(66666) << "key: " << (*it).latin1() << endl;
-			mPressed = parent->pixmap( backgroundPressed((*it)) );
+			QString pressedTmp = backgroundPressed((*it));
+			if(!pressedTmp.isEmpty())
+			{
+				mPressed = parent->pixmap(pressedTmp);
+				gotBack = true;
+			}
 		}
-		else if( (*it) == "darken" )
+		else if((*it) == "darken")
 		{
 			// take background and darken the buttons rectangle
 			// FIXME: what KPixmapEffect causes the desired effect?
 			//        intensity is the wrong one
 			KPixmap temp = parent->pixmap(parser()["backgroundimage"][1]);
 			mPressed = (QPixmap)KPixmapEffect::intensity ( temp, 1.2f );
+			gotBack = true;
 		}
+		if(gotBack)
+			break;
+	}
+
+	if(!gotBack)
+	{
+		kdDebug(66666) << k_funcinfo << "Couldn't find valid background for button '" <<
+			mTitle << "', dafulting to backgroundimage" << endl;
+		mPressed = parent->pixmap(parser()["backgroundimage"][1]);
 	}
 
 	// playlistbutton has to show if playlistwindow is open
 	// right after the button appears on screen
-	if ( mTitle == "playlistbutton" )
+	if (mTitle=="playlistbutton")
 	{
-	if ( napp->playlist()->listVisible() )
-		mShowPressed = true;
+		mShowPressed = napp->playlist()->listVisible();
+		connect( napp->player(), SIGNAL(playlistShown()), this, SLOT(slotPlaylistShown()) );
+		connect( napp->player(), SIGNAL(playlistHidden()), this, SLOT(slotPlaylistHidden()) );
+	}
+	else if ( mTitle=="equalizeroffbutton") // same goes for EQ buttons
+	{
+		mShowPressed = (!napp->vequalizer()->isEnabled());
+		connect( napp->vequalizer(), SIGNAL(enabled(bool)), SLOT(slotEqEnabled(bool)));
+	}
+	else if (mTitle=="equalizeronbutton")
+	{
+		mShowPressed = napp->vequalizer()->isEnabled();
+		connect( napp->vequalizer(), SIGNAL(enabled(bool)), SLOT(slotEqEnabled(bool)));
 	}
 }
 
@@ -93,7 +124,13 @@ QString KJButton::tip()
 	else if (mTitle=="repeatbutton")
 		str=i18n("Loop");
 	else if (mTitle=="equalizerbutton")
-		str="";
+		str=i18n("Show Equalizer Window");
+	else if (mTitle=="equalizeronbutton")
+		str=i18n("Turn on Equalizer");
+	else if (mTitle=="equalizeroffbutton")
+		str=i18n("Turn off Equalizer");
+	else if (mTitle=="equalizerresetbutton")
+		str=i18n("Reset Equalizer");
 	else if (mTitle=="nextsongbutton")
 		str=i18n("Next");
 	else if (mTitle=="previoussongbutton")
@@ -103,7 +140,7 @@ QString KJButton::tip()
 	else if (mTitle=="rewindbutton")
 		str=i18n("Rewind");
 	else if (mTitle=="preferencesbutton")
-		str=i18n("Preferences");
+		str=i18n("K-Jöfol Preferences");
 	else if (mTitle=="dockmodebutton")
 		str=i18n("Switch to dockmode");
 	else if (mTitle=="undockmodebutton")
@@ -115,12 +152,12 @@ QString KJButton::tip()
 void KJButton::paint(QPainter *, const QRect &)
 {
 	if (mShowPressed)
-		bitBlt(parent(), rect().topLeft(), &mPressed, rect(), Qt::CopyROP);
+		bitBlt(KJWidget::parent(), rect().topLeft(), &mPressed, rect(), Qt::CopyROP);
 }
 
 bool KJButton::mousePress(const QPoint &)
 {
-	bitBlt(parent(), rect().topLeft(), &mPressed, rect(), Qt::CopyROP);
+	bitBlt(KJWidget::parent(), rect().topLeft(), &mPressed, rect(), Qt::CopyROP);
 	return true;
 }
 
@@ -133,18 +170,25 @@ void KJButton::showPressed(bool b)
 		repaint(false); // repaint with default image (player-background)
 }
 
-void KJButton::playlistShown(void)
+void KJButton::slotPlaylistShown(void)
 {
-//	kdDebug(66666) << "KJButton::playlistShown()" << endl;
-	if (mTitle=="playlistbutton")
-		showPressed(true);
+//	kdDebug(66666) << "KJButton::slotPlaylistShown()" << endl;
+	showPressed(true);
 }
 
-void KJButton::playlistHidden(void)
+void KJButton::slotPlaylistHidden(void)
 {
-//	kdDebug(66666) << "KJButton::playlistHidden()" << endl;
-	if (mTitle=="playlistbutton")
-		showPressed(false);
+//	kdDebug(66666) << "KJButton::slotPlaylistHidden()" << endl;
+	showPressed(false);
+}
+
+void KJButton::slotEqEnabled(bool on)
+{
+//	kdDebug(66666) << "KJButton::slotEqEnabled(" << on << ") for " << mTitle << endl;
+	if (mTitle=="equalizeronbutton")
+		showPressed(on);
+	else if (mTitle=="equalizeroffbutton")
+		showPressed(!on);
 }
 
 void KJButton::mouseRelease(const QPoint &, bool in)
@@ -157,11 +201,11 @@ void KJButton::mouseRelease(const QPoint &, bool in)
 
 	// now, find what widget I am and do the proper action
 	if (mTitle=="closebutton")
-		parent()->close();
+		KJWidget::parent()->close();
 	else if (mTitle=="minimizebutton")
-		parent()->minimize();
+		KJWidget::parent()->minimize();
 	else if (mTitle=="aboutbutton")
-		parent()->helpMenu()->aboutApplication();
+		KJWidget::parent()->helpMenu()->aboutApplication();
 	else if (mTitle=="stopbutton")
 		napp->player()->stop();
 	else if (mTitle=="playbutton")
@@ -170,15 +214,32 @@ void KJButton::mouseRelease(const QPoint &, bool in)
 		napp->player()->playpause();
 	else if (mTitle=="openfilebutton")
 	{
-		KURL file(KFileDialog::getOpenURL(0, napp->mimeTypes(), parent(),
-		                                  i18n("Select File to Play")));
-		if (!file.isMalformed())
+		KURL file(KFileDialog::getOpenURL(0, napp->mimeTypes(), KJWidget::parent(), i18n("Select File to Play")));
+		if (file.isValid())
 			napp->player()->openFile(file);
 	}
 	else if (mTitle=="playlistbutton")
 		napp->player()->toggleListView();
 	else if (mTitle=="repeatbutton")
 	{
+		KPopupMenu *loopMenu = new KPopupMenu(KJWidget::parent(),"loopMenu");
+		int selectedItem = 0;
+
+		loopMenu->setCheckable(true);
+		loopMenu->insertTitle(i18n("Loop Style"));
+		loopMenu->insertItem(i18n("&None"), static_cast<int>(Player::None));
+		loopMenu->insertItem(i18n("&Song"), static_cast<int>(Player::Song));
+		loopMenu->insertItem(i18n("&Playlist"), static_cast<int>(Player::Playlist));
+		loopMenu->insertItem(i18n("&Random"), static_cast<int>(Player::Random));
+
+		loopMenu->setItemChecked(static_cast<int>(napp->player()->loopStyle()), true); // select current loopstyle in menu
+		selectedItem = loopMenu->exec(QCursor::pos());
+		if (selectedItem != -1)
+			napp->player()->loop(selectedItem); // set new loopstyle
+
+		delete loopMenu;
+
+/*
 		if ( napp->player()->loopStyle() == 1)
 		{
 //			kdDebug(66666) << "loop song is OFF" << endl;
@@ -194,9 +255,33 @@ void KJButton::mouseRelease(const QPoint &, bool in)
 			napp->player()->loop( Player::Song );
 			showPressed ( true );
 		}
+*/
 	}
 	else if (mTitle=="equalizerbutton")
-		;
+	{
+		napp->equalizerView();
+	}
+	else if (mTitle=="equalizeronbutton")
+	{
+		if (!napp->vequalizer()->isEnabled())
+			napp->vequalizer()->enable();
+	}
+	else if (mTitle=="equalizeroffbutton")
+	{
+		if (napp->vequalizer()->isEnabled())
+			napp->vequalizer()->disable();
+	}
+	else if (mTitle=="equalizerresetbutton")
+	{
+		for (int band=0; band<napp->vequalizer()->bands(); band++)
+			napp->vequalizer()->band(band).setLevel(0);
+	/*
+		// That preset resets to 6 bands, that's not what we want
+		VPreset set = napp->vequalizer()->presetByName("Zero");
+		if (set) // tests if that preset is valid
+			set.load();
+	*/
+	}
 	else if (mTitle=="nextsongbutton")
 		napp->player()->forward();
 	else if (mTitle=="previoussongbutton")
@@ -206,11 +291,11 @@ void KJButton::mouseRelease(const QPoint &, bool in)
 	else if (mTitle=="rewindbutton")
 		napp->player()->skipTo(napp->player()->getTime()-10000);
 	else if (mTitle=="preferencesbutton")
-		napp->preferences();
+		napp->preferencesBox()->show(static_cast<CModule *>(KJWidget::parent()->prefs()));
 	else if (mTitle=="dockmodebutton")
-		parent()->switchToDockmode();
+		KJWidget::parent()->switchToDockmode();
 	else if (mTitle=="undockmodebutton")
-		parent()->returnFromDockmode();
+		KJWidget::parent()->returnFromDockmode();
 	else
 		kdDebug(66666) << "unknown buttontype: " << mTitle.latin1() << endl;
 }
