@@ -79,7 +79,8 @@ class WaSkin : public QWidget, public UserInterface {
     void menuEvent();
     void minimizeEvent();
     void shadeEvent();
-    void closeEvent();
+    void doUnload();
+    void doClose();
 
     // balance
     void balanceSliderPressed();
@@ -106,9 +107,10 @@ class WaSkin : public QWidget, public UserInterface {
     void slotStopped();
     void slotPaused();
 
-     WaSkinModel *skinModel() { return waSkinModel; }
-     WaSkinManager *skinManager() { return waSkinManager; }
-  
+    WaSkinModel *skinModel() { return waSkinModel; }
+    WaSkinManager *skinManager() { return waSkinManager; }
+    WaInfo *skinInfo() { return waInfo; }
+    
   protected:
     void updateLoopStyle();
 
