@@ -32,41 +32,16 @@ extern int XShmGetEventBase( Display* );
 
 #define TIMEOUT		15	// 15 seconds
 
-#ifndef HAVE_XINE_1
-#define xine_open_video_driver(xine, id, type, visual) \
-	xine_load_video_output_plugin(config, (char *)id, type, visual)
-#define xine_gui_send_vo_data(stream, type, data) \
-	vo_port->gui_data_exchange(vo_port, type, data)
-#define xine_event_create_listener_thread(queue, evtcb, obj) \
-	xine_register_event_listener(queue, evtcb, obj)
-#define xine_event_new_queue(stream) \
-	stream
-#define xine_event_dispose_queue(queue) \
-	xine_remove_event_listener(queue, xine_handle_event)
-
-#define XINE_STATUS_PLAY		XINE_PLAY
-#define XINE_EVENT_UI_PLAYBACK_FINISHED	XINE_EVENT_PLAYBACK_FINISHED
-#define XINE_VISUAL_TYPE_X11		VISUAL_TYPE_X11
-#define XINE_GUI_SEND_COMPLETION_EVENT	GUI_DATA_EX_COMPLETION_EVENT
-#define XINE_GUI_SEND_DRAWABLE_CHANGED	GUI_DATA_EX_DRAWABLE_CHANGED
-#define XINE_GUI_SEND_EXPOSE_EVENT	GUI_DATA_EX_EXPOSE_EVENT
-#endif
-
 using namespace Arts;
 
 
-#ifdef HAVE_XINE_1
 // Global xine pointer
 static xine_t		*xine_shared	 = NULL;
-#endif
 static pthread_mutex_t	 xine_mutex	 = PTHREAD_MUTEX_INITIALIZER;
-#ifdef HAVE_XINE_1
 static pthread_cond_t	 xine_cond	 = PTHREAD_COND_INITIALIZER;
 static int		 xineRefCount	 = 0;
-#endif
 static bool		 xineForceXShm	 = false;
 
-#ifdef HAVE_XINE_1
 static void xine_init_routine()
 {
     const char *id;
@@ -80,8 +55,8 @@ static void xine_init_routine()
 
     // Check default video output driver
     id = xine_config_register_string (xine_shared, "video.driver",
-				      "auto", "video driver to use",
-				      NULL, 10, NULL, NULL);
+                                      "auto", "video driver to use",
+                                      NULL, 10, NULL, NULL);
 
     xineForceXShm = (id && !strcasecmp( id, "XShm" ));
 
@@ -159,82 +134,56 @@ static void xine_shared_exit( xine_t * )
     }
     pthread_mutex_unlock( &xine_mutex );
 }
-#endif
 
 int ao_fifo_arts_delay()
 {
     return (int)(1000 * Arts::AudioSubSystem::the()->outputDelay());
 }
 
-xinePlayObject_impl::xinePlayObject_impl()
-    : mrl( "" ), xine( 0 ), stream( 0 ), queue( 0 ), ao_port( 0 ), vo_port( 0 )
+xinePlayObject_impl::xinePlayObject_impl(bool audioOnly)
+    : mrl( "" ), xine( 0 ), stream( 0 ), queue( 0 ), ao_port( 0 ), vo_port( 0 ), audioOnly(audioOnly)
 {
-    XInitThreads();
 
-    if (!(display = XOpenDisplay( NULL )))
+    if (!audioOnly)
     {
-	arts_fatal( "could not open X11 display" );
+        XInitThreads();
+
+        if (!(display = XOpenDisplay( NULL )))
+  	{
+			arts_fatal( "could not open X11 display" );
+	}
+
+    	XFlush( display );
+
+	    // Create a special window for uninterrupted X11 communication
+    	xcomWindow = XCreateSimpleWindow( display, DefaultRootWindow( display ),
+					  0, 0, 1, 1, 0, 0, 0 );
+
+	XSelectInput( display, xcomWindow, ExposureMask );
     }
-
-    XFlush( display );
-
-    // Create a special window for uninterrupted X11 communication
-    xcomWindow = XCreateSimpleWindow( display, DefaultRootWindow( display ),
-				       0, 0, 1, 1, 0, 0, 0 );
-
-    XSelectInput( display, xcomWindow, ExposureMask );
-
     pthread_mutex_init( &mutex, 0 );
 
-    // Initialize X11 properties
-    xcomAtomQuit	   = XInternAtom( display, "VPO_INTERNAL_EVENT", False );
-    xcomAtomResize	   = XInternAtom( display, "VPO_RESIZE_NOTIFY", False );
-    screen		   = DefaultScreen( display );
-    shmCompletionType	   = (XShmQueryExtension( display ) == True)
-			     ? XShmGetEventBase( display ) + ShmCompletion : -1;
+    if (!audioOnly)
+    {
+    	// Initialize X11 properties
+    	xcomAtomQuit	   = XInternAtom( display, "VPO_INTERNAL_EVENT", False );
+	xcomAtomResize	   = XInternAtom( display, "VPO_RESIZE_NOTIFY", False );
+	screen		   = DefaultScreen( display );
+	shmCompletionType	   = (XShmQueryExtension( display ) == True)
+				   ?  XShmGetEventBase( display ) + ShmCompletion : -1;
 
-    width		   = 0;
-    height		   = 0;
-    dscbTimeOut		   = 0;
+        width		   = 0;
+        height		   = 0;
+        dscbTimeOut		   = 0;
 
-    // Initialize xine visual structure
-    visual.display	   = display;
-    visual.screen	   = screen;
-    visual.d		   = xcomWindow;
-    visual.dest_size_cb	   = &dest_size_cb;
-    visual.frame_output_cb = &frame_output_cb;
-    visual.user_data	   = this;
-#ifndef HAVE_XINE_1
-    visual.display_ratio   = 1.0;
-
-    const char *default_driver;
-    string config_file = string( getenv( "HOME" )).append( "/.xine/config" );
-
-    config = xine_config_file_init( (char *)config_file.c_str() );
-
-    // Disable OSD
-    config->register_bool( config, (char *)"misc.osd_display", 0,
-			   (char *)"disabled for KDE", 0, 0, 0 );
-    config->update_num( config, (char *)"misc.osd_display", 0 );
-
-    // Disable xine logo
-    config->register_string( config, (char *)"misc.logo_mrl", (char *)"",
-			     (char *)"disabled for KDE", 0, 0, 0 );
-    config->update_string( config, (char *)"misc.logo_mrl", (char *)"" );
-
-    // Get default video output driver
-    default_driver = config->register_string( config,
-					      (char *)"video.driver",
-					      (char *)"auto",
-					      (char *)"video driver to use",
-					      NULL, NULL, NULL );
-
-    pthread_mutex_lock( &xine_mutex );
-
-    xineForceXShm = (default_driver && !strcasecmp( default_driver, "XShm" ));
-
-    pthread_mutex_unlock( &xine_mutex );
-#endif
+    	// Initialize xine visual structure
+        visual.display	   = display;
+        visual.screen	   = screen;
+        visual.d		   = xcomWindow;
+        visual.dest_size_cb	   = &dest_size_cb;
+        visual.frame_output_cb = &frame_output_cb;
+        visual.user_data	   = this;
+    }
 
     // Initialize audio and video details
     Arts::SoundServerV2 server = Arts::Reference( "global:Arts_SoundServerV2" );
@@ -243,11 +192,11 @@ xinePlayObject_impl::xinePlayObject_impl()
     audio.bits_per_sample  = 0;
 
     flpos		   = 0.0;
-
-    if (pthread_create( &thread, 0, pthread_start_routine, this ))
-    {
-	arts_fatal( "could not create thread" );
-    }
+    if (!audioOnly)
+        if (pthread_create( &thread, 0, pthread_start_routine, this ))
+    	{
+	    arts_fatal( "could not create thread" );
+        }
 }
 
 xinePlayObject_impl::~xinePlayObject_impl()
@@ -264,12 +213,17 @@ xinePlayObject_impl::~xinePlayObject_impl()
     event.xclient.message_type	= xcomAtomQuit;
     event.xclient.format	= 32;
 
-    XSendEvent( display, xcomWindow, True, 0, &event );
+    if (!audioOnly)
+    {
 
-    XFlush( display );
+        XSendEvent( display, xcomWindow, True, 0, &event );
 
-    // Wait for the thread to die
-    pthread_join( thread, 0 );
+        XFlush( display );
+
+        // Wait for the thread to die
+        pthread_join( thread, 0 );
+
+    }
 
     // Destroy stream, xine and related resources
     if (stream != 0)
@@ -277,29 +231,23 @@ xinePlayObject_impl::~xinePlayObject_impl()
 	halt();
 
 	xine_event_dispose_queue( queue );
-#ifdef HAVE_XINE_1
 	xine_dispose( stream );
 	xine_close_audio_driver( xine, ao_port );
 	xine_close_video_driver( xine, vo_port );
-#endif
     }
     if (xine != 0)
     {
-#ifdef HAVE_XINE_1
 	xine_shared_exit( xine );
-#else
-	xine_exit( xine );
-#endif
     }
-#ifndef HAVE_XINE_1
-    config->dispose( config );
-#endif
 
     pthread_mutex_destroy( &mutex );
 
-    XSync( display, False );
-    XDestroyWindow( display, xcomWindow );
-    XCloseDisplay( display );
+    if (!audioOnly)
+    {
+        XSync( display, False );
+        XDestroyWindow( display, xcomWindow );
+        XCloseDisplay( display );
+    }
 }
 
 bool xinePlayObject_impl::loadMedia( const string &url )
@@ -312,62 +260,56 @@ bool xinePlayObject_impl::loadMedia( const string &url )
 
     if (stream == 0)
     {
-#ifdef HAVE_XINE_1
 	if (xine == 0)
 	{
 	    xine = xine_shared_init();
 	}
-#endif
 
 	ao_port = init_audio_out_plugin( xine, &audio, &ao_driver );
 
-	if (xineForceXShm)
+	if (xineForceXShm && !audioOnly)
 	{
 	    vo_port = xine_open_video_driver( xine, "XShm",
 					      XINE_VISUAL_TYPE_X11,
 					      (void *)&visual );
 	}
-	if (vo_port == 0)
+	if (vo_port == 0 && !audioOnly)
 	{
 	    vo_port = xine_open_video_driver( xine, "Xv",
 					      XINE_VISUAL_TYPE_X11,
 					      (void *)&visual );
 	}
-	if (vo_port == 0)
+	if (vo_port == 0 && !audioOnly)
 	{
 	    vo_port = xine_open_video_driver( xine, "XShm",
 					      XINE_VISUAL_TYPE_X11,
 					      (void *)&visual );
 	}
-	if (vo_port == 0)
+	if (vo_port == 0 && !audioOnly)
 	{
 	    vo_port = xine_open_video_driver( xine, "OpenGL",
 					      XINE_VISUAL_TYPE_X11,
 					      (void *)&visual );
 	}
-	if (ao_port != 0 && vo_port != 0)
+	if (vo_port == 0)
+	{
+	    vo_port = xine_open_video_driver( xine, 0,
+					      XINE_VISUAL_TYPE_NONE, 0 );
+	}
+
+	if (ao_port != 0 && vo_port != 0 )
 	{
-#ifdef HAVE_XINE_1
 	    stream = xine_stream_new( xine, ao_port, vo_port );
-#else
-	    stream = xine = xine_init( vo_port, ao_port, config );
-#endif
 
 	    if (stream != 0)
 	    {
-#ifdef HAVE_XINE_1
 		xine_set_param( stream, XINE_PARAM_AUDIO_CHANNEL_LOGICAL, 0 );
 		xine_set_param( stream, XINE_PARAM_SPU_CHANNEL, -1 );
-#else
-		xine_select_audio_channel( xine, 0 );
-		xine_select_spu_channel( xine, -1 );
-#endif
 
-		queue = xine_event_new_queue( stream );
+   	    	queue = xine_event_new_queue( stream );
 		xine_event_create_listener_thread( queue, xine_handle_event, this );
 	    }
 	}
-#ifdef HAVE_XINE_1
 	if (stream == 0)
 	{
 	    if (ao_port != 0)
@@ -381,7 +323,6 @@ bool xinePlayObject_impl::loadMedia( const string &url )
 		vo_port = 0;
 	    }
 	}
-#endif
     }
 
     if (stream != 0)
@@ -394,9 +335,7 @@ bool xinePlayObject_impl::loadMedia( const string &url )
 
 	    clearWindow();
 	}
-#ifdef HAVE_XINE_1
 	if ((result = xine_open( stream, url.c_str() )))
-#endif
 	{
 	    mrl = url;
 	}
@@ -406,9 +345,6 @@ bool xinePlayObject_impl::loadMedia( const string &url )
 
 	width = 0;
 	height = 0;
-#ifndef HAVE_XINE_1
-	result = true;
-#endif
     }
 
     pthread_mutex_unlock( &mutex );
@@ -428,9 +364,8 @@ poTime xinePlayObject_impl::currentTime()
 
     pthread_mutex_lock( &mutex );
 
-    if (stream != 0 && mrl != "")
+    if (stream != 0 && !mrl.empty())
     {
-#ifdef HAVE_XINE_1
 	if (xine_get_pos_length( stream, 0, &pos_time, 0 ))
 	{
 	    streamPosition = pos_time;
@@ -439,9 +374,6 @@ poTime xinePlayObject_impl::currentTime()
 	{
 	    pos_time = streamPosition;
 	}
-#else
-	pos_time = (1000 * xine_get_current_time( xine ));
-#endif
 
 	time.seconds = pos_time / 1000;
 	time.ms = pos_time % 1000;
@@ -463,9 +395,8 @@ poTime xinePlayObject_impl::overallTime()
 
     pthread_mutex_lock( &mutex );
 
-    if (stream != 0 && mrl != "")
+    if (stream != 0 && !mrl.empty())
     {
-#ifdef HAVE_XINE_1
 	if (xine_get_pos_length( stream, 0, 0, &length_time ))
 	{
 	    streamLength = length_time;
@@ -474,9 +405,6 @@ poTime xinePlayObject_impl::overallTime()
 	{
 	    length_time = streamLength;
 	}
-#else
-	length_time = (1000 * xine_get_stream_length( xine ));
-#endif
 
 	if (length_time <= 0)
 	{
@@ -502,11 +430,7 @@ poCapabilities xinePlayObject_impl::capabilities()
 
     pthread_mutex_lock( &mutex );
 
-#ifdef HAVE_XINE_1
     n = (stream == 0) ? 0 : xine_get_stream_info( stream, XINE_STREAM_INFO_SEEKABLE );
-#else
-    n = 1;
-#endif
 
     pthread_mutex_unlock( &mutex );
 
@@ -526,11 +450,7 @@ poState xinePlayObject_impl::state()
 
     if (stream == 0 || xine_get_status( stream ) != XINE_STATUS_PLAY)
 	state = posIdle;
-#ifdef HAVE_XINE_1
     else if (xine_get_param( stream, XINE_PARAM_SPEED ) == XINE_SPEED_PAUSE)
-#else
-    else if (xine_get_speed( xine ) == SPEED_PAUSE)
-#endif
 	state = posPaused;
     else
 	state = posPlaying;
@@ -540,59 +460,6 @@ poState xinePlayObject_impl::state()
     return state;
 }
 
-long xinePlayObject_impl::x11Snapshot()
-{
-    long pixmap = -1;
-
-    pthread_mutex_lock( &mutex );
-
-    if (stream != 0 && xine_get_status( stream ) == XINE_STATUS_PLAY)
-    {
-	// FIXME: snapshot...
-	pixmap = (long)-1;
-    }
-    pthread_mutex_unlock( &mutex );
-
-    return pixmap;
-}
-
-void xinePlayObject_impl::x11WindowId( long window )
-{
-    pthread_mutex_lock( &mutex );
-
-    if (window == -1)
-    {
-	window = xcomWindow;
-    }
-
-    if ((Window)window != visual.d)
-    {
-	XLockDisplay( display );
-
-	// Change window and set event mask of new window
-	visual.d = window;
-
-	XSelectInput( display, window, ExposureMask );
-
-	if (stream != 0)
-	{
-	    resizeNotify();
-
-	    xine_gui_send_vo_data( stream,
-				   XINE_GUI_SEND_DRAWABLE_CHANGED,
-				   (void *)window );
-	}
-
-	XUnlockDisplay( display );
-    }
-    pthread_mutex_unlock( &mutex );
-}
-
-long xinePlayObject_impl::x11WindowId()
-{
-    return (visual.d == xcomWindow) ? (long)-1 : visual.d;
-}
-
 void xinePlayObject_impl::play()
 {
     pthread_mutex_lock( &mutex );
@@ -601,26 +468,14 @@ void xinePlayObject_impl::play()
     {
 	if (xine_get_status( stream ) == XINE_STATUS_PLAY)
 	{
-#ifdef HAVE_XINE_1
 	    if (xine_get_param( stream, XINE_PARAM_SPEED ) == XINE_SPEED_PAUSE)
-#else
-	    if (xine_get_speed( xine ) == SPEED_PAUSE)
-#endif
 	    {
-#ifdef HAVE_XINE_1
 	        xine_set_param( stream, XINE_PARAM_SPEED, XINE_SPEED_NORMAL );
-#else
-		xine_set_speed( xine, SPEED_NORMAL );
-#endif
 	    }
 	}
-	else if (mrl != "")
+	else if (!mrl.empty())
 	{
-#ifdef HAVE_XINE_1
 	    xine_play( stream, 0, 0 );
-#else
-	    xine_play( xine, (char *)mrl.c_str(), 0, 0 );
-#endif
 	}
     }
     pthread_mutex_unlock( &mutex );
@@ -651,19 +506,11 @@ void xinePlayObject_impl::seek( const class poTime &t )
     if (stream != 0 && xine_get_status( stream ) == XINE_STATUS_PLAY)
     {
 	int seekPosition = (1000 * t.seconds) + t.ms;
-#ifdef HAVE_XINE_1
 	int paused = (xine_get_param( stream, XINE_PARAM_SPEED ) == XINE_SPEED_PAUSE);
-#else
-	int paused = (xine_get_speed( xine ) == SPEED_PAUSE);
-#endif
 
 	ao_fifo_clear( ao_driver, 1 );
 
-#ifdef HAVE_XINE_1
 	if (xine_play( stream, 0, seekPosition ))
-#else
-	if (xine_play( xine, (char *)mrl.c_str(), 0, (seekPosition / 1000) ))
-#endif
 	{
 	    if (seekPosition >= 0 && seekPosition <= streamLength)
 	    {
@@ -673,11 +520,7 @@ void xinePlayObject_impl::seek( const class poTime &t )
 
 	if (paused)
 	{
-#ifdef HAVE_XINE_1
 	    xine_set_param( stream, XINE_PARAM_SPEED, XINE_SPEED_PAUSE );
-#else
-	    xine_set_speed( xine, SPEED_PAUSE );
-#endif
 	}
 
 	ao_fifo_clear( ao_driver, 0 );
@@ -693,11 +536,7 @@ void xinePlayObject_impl::pause()
     {
 	ao_fifo_clear( ao_driver, 1 );
 
-#ifdef HAVE_XINE_1
 	xine_set_param( stream, XINE_PARAM_SPEED, XINE_SPEED_PAUSE );
-#else
-	xine_set_speed( xine, SPEED_PAUSE );
-#endif
     }
     pthread_mutex_unlock( &mutex );
 }
@@ -750,6 +589,8 @@ void xinePlayObject_impl::xineEvent( const xine_event_t &event )
 
 void xinePlayObject_impl::clearWindow()
 {
+    if (audioOnly) return;
+
     Window root;
     unsigned int u, w, h;
     int x, y, screen;
@@ -773,6 +614,8 @@ void xinePlayObject_impl::frameOutput( int &x, int &y,
 				       int displayWidth, int displayHeight,
 				       double displayPixelAspect, bool dscb )
 {
+    if (audioOnly) return;
+
     Window child, root;
     unsigned int u;
     int n;
@@ -822,6 +665,7 @@ void xinePlayObject_impl::frameOutput( int &x, int &y,
 
 void xinePlayObject_impl::resizeNotify()
 {
+    if (audioOnly) return;
     XEvent event;
 
     // Resize notify signal for front-ends
@@ -850,6 +694,8 @@ void xinePlayObject_impl::eventLoop()
 	if (event.type == Expose && event.xexpose.count == 0 &&
 	    event.xexpose.window == visual.d)
 	{
+	    pthread_mutex_lock( &mutex );
+
 	    if (stream != 0)
 	    {
 		xine_gui_send_vo_data( stream,
@@ -860,12 +706,19 @@ void xinePlayObject_impl::eventLoop()
 	    {
 		clearWindow();
 	    }
+	    pthread_mutex_unlock( &mutex );
 	}
-	else if (event.type == shmCompletionType && stream != 0)
+	else if (event.type == shmCompletionType)
 	{
-	    xine_gui_send_vo_data( stream,
-				   XINE_GUI_SEND_COMPLETION_EVENT,
-				   &event );
+	    pthread_mutex_lock( &mutex );
+
+	    if (stream != 0)
+	    {
+		xine_gui_send_vo_data( stream,
+				       XINE_GUI_SEND_COMPLETION_EVENT,
+				       &event );
+	    }
+	    pthread_mutex_unlock( &mutex );
 	}
     }
     while (event.type != ClientMessage ||
@@ -873,4 +726,59 @@ void xinePlayObject_impl::eventLoop()
 	   event.xclient.window != xcomWindow);
 }
 
+void xineVideoPlayObject_impl::x11WindowId( long window )
+{
+    pthread_mutex_lock( &mutex );
+
+    if (window == -1)
+    {
+	window = xcomWindow;
+    }
+
+    if ((Window)window != visual.d)
+    {
+	XLockDisplay( display );
+
+	// Change window and set event mask of new window
+	visual.d = window;
+
+	XSelectInput( display, window, ExposureMask );
+
+	if (stream != 0)
+	{
+	    resizeNotify();
+
+	    xine_gui_send_vo_data( stream,
+				   XINE_GUI_SEND_DRAWABLE_CHANGED,
+				   (void *)window );
+	}
+
+	XUnlockDisplay( display );
+    }
+    pthread_mutex_unlock( &mutex );
+}
+
+long xineVideoPlayObject_impl::x11WindowId()
+{
+    return (visual.d == xcomWindow) ? (long)-1 : visual.d;
+}
+
+long xineVideoPlayObject_impl::x11Snapshot()
+{
+    long pixmap = -1;
+
+    pthread_mutex_lock( &mutex );
+
+    if (stream != 0 && xine_get_status( stream ) == XINE_STATUS_PLAY)
+    {
+	// FIXME: snapshot...
+	pixmap = (long)-1;
+    }
+    pthread_mutex_unlock( &mutex );
+
+    return pixmap;
+}
+
 REGISTER_IMPLEMENTATION(xinePlayObject_impl);
+REGISTER_IMPLEMENTATION(xineAudioPlayObject_impl);
+REGISTER_IMPLEMENTATION(xineVideoPlayObject_impl);
